@@ -7,8 +7,6 @@
 //  $ cargo run --example s-expr file1.md file2.md ...
 //  $ cat file.md | cargo run --example s-expr
 
-extern crate comrak;
-
 /// Spaces to indent nested nodes
 const INDENT: usize = 4;
 
@@ -16,7 +14,7 @@ const INDENT: usize = 4;
 const CLOSE_NEWLINE: bool = false;
 
 use comrak::nodes::{AstNode, NodeValue};
-use comrak::{parse_document, Arena, ComrakExtensionOptions, ComrakOptions};
+use comrak::{parse_document, Arena, ExtensionOptions, Options};
 use std::env;
 use std::error::Error;
 use std::fs::File;
@@ -32,29 +30,20 @@ fn iter_nodes<'a, W: Write>(
     macro_rules! try_node_inline {
         ($node:expr, $name:ident) => {{
             if let $name(t) = $node {
-                return write!(
-                    writer,
-                    concat!(stringify!($name), "({:?})"),
-                    String::from_utf8_lossy(&t)
-                );
+                return write!(writer, concat!(stringify!($name), "({:?})"), t,);
             }
         }};
     }
 
     match &node.data.borrow().value {
-        Text(t) => write!(writer, "{:?}", String::from_utf8_lossy(&t))?,
+        Text(t) => write!(writer, "{:?}", t)?,
         value => {
             try_node_inline!(value, FootnoteDefinition);
             try_node_inline!(value, FootnoteReference);
             try_node_inline!(value, HtmlInline);
 
             if let Code(code) = value {
-                return write!(
-                    writer,
-                    "Code({:?}, {})",
-                    String::from_utf8_lossy(&code.literal),
-                    code.num_backticks
-                );
+                return write!(writer, "Code({:?}, {})", code.literal, code.num_backticks);
             }
 
             let has_blocks = node.children().any(|c| c.data.borrow().value.block());
@@ -85,19 +74,25 @@ fn iter_nodes<'a, W: Write>(
 fn dump(source: &str) -> io::Result<()> {
     let arena = Arena::new();
 
-    let opts = ComrakOptions {
-        extension: ComrakExtensionOptions {
-            strikethrough: true,
-            tagfilter: true,
-            table: true,
-            autolink: true,
-            tasklist: true,
-            superscript: true,
-            footnotes: true,
-            description_lists: true,
-            ..ComrakExtensionOptions::default()
-        },
-        ..ComrakOptions::default()
+    let extension = ExtensionOptions::builder()
+        .strikethrough(true)
+        .tagfilter(true)
+        .table(true)
+        .autolink(true)
+        .tasklist(true)
+        .superscript(true)
+        .footnotes(true)
+        .description_lists(true)
+        .multiline_block_quotes(true)
+        .math_dollars(true)
+        .math_code(true)
+        .wikilinks_title_after_pipe(true)
+        .wikilinks_title_before_pipe(true)
+        .build();
+
+    let opts = Options {
+        extension,
+        ..Options::default()
     };
 
     let doc = parse_document(&arena, source, &opts);
